from setuptools import setup

setup(name='prob_dist_sd',
      version='0.1',
      description='Gaussian and Binomial distributions',
      packages=['prob_dist_sd'],
      author = 'Swastik Dashore',
      author_email = 'swastik01tc@gmail.com',
      zip_safe=False)
